@@ -2,54 +2,51 @@
 '''
 @author: M. Bernt
 
-This is a confidential release. Do not redistribute without 
-permission of the author (bernt@informatik.uni-leipzig.de).
+compare the features given in two files (gb or bed).
+for each feature f2 from file2 the feature f1 from file1 is searched which
+intersects most and f2 is covered more than the given cutoff.
+coverage is computed as the size of the intersection / the length of the feature.
 
-compare the features given in two files (gb or bed). 
-for each feature f2 from file2 the feature f1 from file1 is searched which 
-intersects most and f2 is covered more than the given cutoff. 
-coverage is computed as the size of the intersection / the length of the feature. 
-
-the output is: 
+the output is:
 accession, f1.name, f2.name, standdiff, f1.cover, f2.cover, f1.score, f2.score, dstart, dend, fs
 
-where: 
-stranddiff: is +1 for same strand, -1 different strand  
+where:
+stranddiff: is +1 for same strand, -1 different strand
 fX.cover: intersection/fX.length
 
 dstart|dend f1start-f2start , resp. end
 fs 1 if frameshift for proteins NA otherwise
 
-if perfeature is NOT set then each gene family is treated as a whole.  
-an additional column is added to the output giving the difference of the number of 
-members of the gene family in file1 and file2. 
+if perfeature is NOT set then each gene family is treated as a whole.
+an additional column is added to the output giving the difference of the number of
+members of the gene family in file1 and file2.
 '''
-from __future__ import print_function
-from optparse import OptionParser, OptionGroup
+
+from optparse import OptionGroup, OptionParser
 from os.path import splitext
 from sys import exit, stderr
 
-from mitos.gb import gbfromfile
+from mitos import feature
+from mitos import mitofile
 from mitos.bedfile import bedfromfile
-import mitos.mitofile as mitofile
-import mitos.feature as feature
+from mitos.gb import gbfromfile
 
 
 def featurelist2map(lst):
     """
     create a dictionary for a list of features
-    for each name one name one entry is created in the map containing 
+    for each name one name one entry is created in the map containing
     1. pos : the position of the features with the name
     2. sgn : a sorted list of signs of the features with the name
     3. cnt : the number of features with the name
     3. scr : the sum of the scores of features with the name
 
-    @param[in] lst a list of features 
+    @param[in] lst a list of features
     """
 
     mp = {}
     for f in lst:
-        if not f.name in mp:
+        if f.name not in mp:
             mp[f.name] = {}
             mp[f.name]["pos"] = set()
             mp[f.name]["sgn"] = None
@@ -68,12 +65,12 @@ def featurelist2map(lst):
 
         mp[f.name]["pos"] = mp[f.name]["pos"].union(
             set(range(f.start, f.stop + 1)))
-        if mp[f.name]["sgn"] == None or mp[f.name]["sgn"] == f.strand:
+        if mp[f.name]["sgn"] is None or mp[f.name]["sgn"] == f.strand:
             mp[f.name]["sgn"] = f.strand
         else:
             f.strand = 0
         mp[f.name]["cnt"] += 1
-        if f.score == None:
+        if f.score is None:
             mp[f.name]["scr"] += 0
         else:
             mp[f.name]["scr"] += f.score * (f.stop - f.start + 1)
@@ -84,6 +81,7 @@ def featurelist2map(lst):
 
     return mp
 
+
 usage = "usage: %prog [options] ANNOTATION REFERENCE"
 parser = OptionParser(usage)
 
@@ -161,7 +159,7 @@ elif ext == ".mitos":
 
 feat2 = g2.getfeatures(
     anames=options.aname, fnames=options.fname, atypes=options.atype, ftypes=options.ftype)
-if bname == None:
+if bname is None:
     bname = g2.accession
 
 
@@ -169,22 +167,22 @@ def flist2map(flist, length):
     """
     @param flist feature list
     @param length genome size
-    @return pair fmap, pmap 
-            fmap[N][C] gives a list of parts belonging to feature with name N copy C, 
-            pmap gives the set of positions of the corresponding features 
+    @return pair fmap, pmap
+            fmap[N][C] gives a list of parts belonging to feature with name N copy C,
+            pmap gives the set of positions of the corresponding features
     """
     fmap = {}  # feature map
     pmap = {}  # position map
 
     for f in flist:
-        if f.copy != None:
+        if f.copy is not None:
             c = f.copy
         else:
             c = -1
-        if not f.name in fmap:
+        if f.name not in fmap:
             fmap[f.name] = {}
             pmap[f.name] = {}
-        if not c in fmap[f.name]:
+        if c not in fmap[f.name]:
             fmap[f.name][c] = []
             pmap[f.name][c] = []
 
@@ -200,6 +198,7 @@ def flist2map(flist, length):
 
     return fmap, pmap
 
+
 f1map, p1map = flist2map(feat1, size)
 f2map, p2map = flist2map(feat2, size)
 
@@ -254,7 +253,7 @@ for n1 in f1map:
             f1score = min([f.score for f in f1map[n1][c1]])
         try:
             f1bits = max([f.bitscore for f in f1map[n1][c1]])
-        except:
+        except Exception:
             f1bits = "NA"
 
         if maxmap12[(n1, c1)] != -1 and maxmap21[maxmap12[(n1, c1)]] == (n1, c1):
@@ -271,7 +270,7 @@ for n1 in f1map:
                 f2score = min([f.score for f in f2map[n2][c2]])
             try:
                 f2bits = max([f.bitscore for f in f2map[n2][c2]])
-            except:
+            except Exception:
                 f2bits = "NA"
 
             if n1 == n2 and f1strand == f2strand:
@@ -327,7 +326,7 @@ for n1 in f1map:
 
 # print the elements from feat2 which have no 'partner' in feat1
 for f2 in feat2:
-    if f2.copy != None:
+    if f2.copy is not None:
         f2copy = f2.copy
     else:
         f2copy = -1
@@ -344,7 +343,7 @@ for f2 in feat2:
             f2score = min([f.score for f in f2map[f2.name][f2copy]])
         try:
             f2bits = max([f.bitscore for f in f2map[f2.name][f2copy]])
-        except:
+        except Exception:
             f2bits = "NA"
 
         print(bname, "NA", f2.name,
