@@ -3,18 +3,15 @@
 '''
 @author: M. Bernt
 
-This is a confidential release. Do not redistribute without 
-permission of the author (bernt@informatik.uni-leipzig.de).
-
 get infos from a set of gb-files
 '''
 
-from __future__ import print_function
-from optparse import OptionParser
-from os.path import isfile, isdir
-# import pickle
-from os import listdir
+
 import sys
+from optparse import OptionParser
+from os import listdir
+from os.path import isdir, isfile
+# import pickle
 
 from mitos.gb import gbfromfile
 
@@ -54,7 +51,7 @@ if len(files) == 0:
     sys.exit()
 
 # outfile and outdir given ?
-if options.outfile == None:
+if options.outfile is None:
     ohandle = sys.stdout
 else:
     ohandle = open(options.outfile, "w")
@@ -94,5 +91,5 @@ for arg in files:
     #    print r.authors, r.journal, r.title
 
 # outfile and outdir given ?
-if options.outfile != None:
+if options.outfile is not None:
     ohandle.close()
