@@ -393,6 +393,7 @@ class feature:
         self.stop = stop
         self.strand = strand
         self.method = method
+
         self.translation = translation
         self.score = score
         self.rf = rf
@@ -707,7 +708,7 @@ class feature:
 #                     raise FeatureUnAddable( self, other )
 #
 #         # print translation
-#         return feature( name = prop["name"], type = prop["type"], start = prop["start"], \
+#         return feature( name = prop["name"], tpe = prop["type"], start = prop["start"], \
 #                         stop = prop["stop"], strand = prop["strand"], method = prop["method"],
 #                         translation = prop["translation"], score = prop["score"], \
 #                         rf = prop["rf"], anticodon = prop["anticodon"],
@@ -760,7 +761,7 @@ class feature:
 
         return "%s\t%d\t%d\t%s\t%s\t%s" % (acc, self.start, self.stop + 1, self.getname(), s, self.plusminus())
 
-    def gffstr(self, acc, features):
+    def gffstr(self, acc, features, size):
         """
         @param acc accession for col 1
         @param features all other features
@@ -792,6 +793,8 @@ origin_of_replication
             parts = [x for x in features if x.name == self.name and x.copy == self.copy]
             genestart = parts[0].start
             genestop = parts[-1].stop
+            if genestart > genestop:
+                genestop += size
             if self.type == "gene":
                 genetype = "gene"
                 trnstype = "mRNA"
@@ -833,9 +836,13 @@ origin_of_replication
             rf = str(self.rf)
 
         # exon
+        start, stop = self.start, self.stop
+        if start > stop:
+            stop += size
+
         gff.append("{seqid}\t{source}\t{type}\t{start}\t{end}\t{score}\t{strand}\t{phase}\tParent=transcript_{namep};Name={name}".format(
             seqid=acc, source=self.method, type="exon",
-            start=self.start + 1, end=self.stop + 1, score=s, strand=self.plusminus(),
+            start=start + 1, end=stop + 1, score=s, strand=self.plusminus(),
             phase=rf, namep=self.outputname(anticodon=False, part=False), name=self.outputname(anticodon=False)))
         return "\n".join(gff)
 
