@@ -1,30 +1,33 @@
 '''
 @author: M. Bernt
-
-This is a confidential release. Do not redistribute without 
-permission of the author (bernt@informatik.uni-leipzig.de).
 '''
 
+import logging
 import re
 import sys
-import logging
 from os.path import splitext
-from Bio import GenBank
-from Bio import SeqIO
+
+from Bio import (
+    Data,
+    SeqIO,
+)
 from Bio.Alphabet import IUPAC
-from Bio import Seq
-from Bio import Data
 
 
-from .. import feature
-from .. import mito
-from . import unify
-from .. import sequence
-from ..trna import codon, CodonError, L1, L2, S1, S2
+from mitos import feature
+from mitos import sequence
+from mitos.gb import unify
+from mitos.trna import (
+    codon,
+    CodonError,
+    L1,
+    L2,
+    S1,
+    S2,
+)
 
 
 class gb:
-
     def __init__(self):
 
         self.accession = None
@@ -51,7 +54,7 @@ class gb:
 
     def _add_feature(self, nf):
         """
-        add a feature ..  
+        add a feature ..
         """
         self.features.append(nf)
 
@@ -59,7 +62,7 @@ class gb:
         """
         return a string describing the absence or presence of genes
         @param genes the genes to check for (a list of names)
-        @return comma separated list giving the number of occurences of the genes (sorted by name)        
+        @return comma separated list giving the number of occurences of the genes (sorted by name)
         """
 
         gdict = {}
@@ -69,19 +72,19 @@ class gb:
         for f in self.features:
             try:
                 gdict[f.name] += 1
-            except:
+            except KeyError:
                 gdict[f.name] = 1
 
         return ",".join([str(gdict[g]) for g in sorted(genes)])
 
     def dellowscoreparts(self):
         """
-        delete all parts except one of the same name (those with best score) 
+        delete all parts except one of the same name (those with best score)
         """
 
         bestscores = {}
         for f in self.features:
-            if not f.name in bestscores or ((f.type == "gene" and bestscores[f.name] < f.score) or (f.type != "gene" and bestscores[f.name] > f.score)):
+            if f.name not in bestscores or ((f.type == "gene" and bestscores[f.name] < f.score) or (f.type != "gene" and bestscores[f.name] > f.score)):
                 bestscores[f.name] = f.score
 
         i = 0
@@ -94,13 +97,13 @@ class gb:
 
     def getfeatures(self, anames=None, fnames=None, atypes=None, ftypes=None, astrand=None):
         """
-        get a list of features 
-        \param anames list of allowed feature names (None: everything allowed)
-        \param fnames list of forbidden feature names (None: nothing forbidden)
-        \param atypes list of allowed feature types (None: everything allowed)
-        \param ftypes list of forbidden feature types (None: nothing forbidden)
-        \param astrand allowed strand (None: both strands allowed) 
-        \return list of features
+        get a list of features
+        param anames list of allowed feature names (None: everything allowed)
+        param fnames list of forbidden feature names (None: nothing forbidden)
+        param atypes list of allowed feature types (None: everything allowed)
+        param ftypes list of forbidden feature types (None: nothing forbidden)
+        param astrand allowed strand (None: both strands allowed)
+        return list of features
         """
 
         return [x for x in self.features if x.is_allowed(anames, fnames, atypes, ftypes, astrand)]
@@ -110,16 +113,16 @@ class gb:
     def geneorder(self, anames=None, fnames=None, atypes=None, ftypes=None, signed=True):
         """
         get the gene order as list
-        \param atypes list of allowed feature types (None: everything allowed)
-        \param ftypes list of forbidden feature types (None: nothing forbidden)
-        \param signed make the gene order signed (default: True) 
+        param atypes list of allowed feature types (None: everything allowed)
+        param ftypes list of forbidden feature types (None: nothing forbidden)
+        param signed make the gene order signed (default: True)
         """
 
         features = self.getfeatures(
             anames=anames, fnames=fnames, atypes=atypes, ftypes=ftypes)
         order = []
         for f in features:
-            if signed == True and f.strand < 0:
+            if signed is True and f.strand < 0:
                 # order.append( "-" + f.getname() )
                 order.append("-" + f.name)
             else:
@@ -130,9 +133,9 @@ class gb:
     def is_allowed(self, atax=None, ftax=None):
         """
         checks if the gb file to certain taxonomic groups
-        \param atax list of allowed taxonomic groups or a string of a group  
-        \param ftax forbidden taxonomic groups 
-        \return true iff gb in atax and gb not in ftax
+        param atax list of allowed taxonomic groups or a string of a group
+        param ftax forbidden taxonomic groups
+        return true iff gb in atax and gb not in ftax
         """
 
         if isinstance(atax, str):
@@ -140,18 +143,18 @@ class gb:
         if isinstance(ftax, str):
             ftax = [ftax]
 
-        if atax != None and len(filter(lambda x: x in self.taxonomy, atax)) == 0:
+        if atax is not None and len([x for x in atax if x in self.taxonomy]) == 0:
             return False
-        elif ftax != None and len(filter(lambda x: x in self.taxonomy, ftax)) > 0:
+        elif ftax is not None and len([x for x in ftax if x in self.taxonomy]) > 0:
             return False
 
         return True
 
     def start_stop_subsequence(self, mx=False):
         """
-        get (start,stop, strand) tuples of the sequence such that at start is a 
+        get (start,stop, strand) tuples of the sequence such that at start is a
         start codon and at end a end codon
-        \param max only return maximal sequences, i.e. if there are two sequences 
+        param max only return maximal sequences, i.e. if there are two sequences
         (s1,e) and (s2,e) with s1<s2 then only (s1,e) will be returned
         """
         return self.sequence.start_stop_subsequence(self.transl_table, mx)
@@ -161,22 +164,22 @@ class gbfromfile(gb):
 
     def __init__(self, gbfile):
         """
-        @param gbfile: filename string 
+        @param gbfile: filename string
 
         1. parse circular/linear (from residue_type)
            circular iff residue_type ends with "circular"
         2. parse accession and version (from accession, version, and locus)
-           accession is taken directly, version is parsed from the string given 
+           accession is taken directly, version is parsed from the string given
            by accession.version, additional warnings are printed if the accession
            is not equal to the locus or the accession part of the version string
-        3. parse the complete property and the name of the species 
+        3. parse the complete property and the name of the species
            (from definition, organism, and source)
            - if definition contains the string "complete" the complete property is set
            - name is set to the content of organism
            - a warning is written if source does not start with 'mitochondrion '+name
-           - if source ends with ')' then the common name is taken from the 
+           - if source ends with ')' then the common name is taken from the
              parenthesised part
-        4. size, comment, data_file_division, date, references, taxonomy  is taken directly 
+        4. size, comment, data_file_division, date, references, taxonomy  is taken directly
            from the corresponding entries of the record
         5. sequence is taken directly from sequence with ambiguous DNA (IUPAC) alphabet
         6. transl_table is parsed from all features with a key "transl_table"
@@ -184,51 +187,51 @@ class gbfromfile(gb):
            - the one of the found translation tables is returned
         7. the taxid is parsed from source feature (as the qualifier of the key db_xref)
         8. for each of features (parts):
-        8a. the locations are parsed recursively given some string describing the location 
+        8a. the locations are parsed recursively given some string describing the location
             and the currently active strand initialized to +1:
-           - for a string join(x) or order(x) the method is recursively called 
+           - for a string join(x) or order(x) the method is recursively called
              for each part of the contained comma separated list x (keeping the active strand as is)
-           - for a string complement(x) the method is recursively called for x 
+           - for a string complement(x) the method is recursively called for x
              (with the currently active strand inverted)
-           - otherwise all numbers are parsed from the string and a position is added 
+           - otherwise all numbers are parsed from the string and a position is added
                on the currently active strand
              * if one number n is found a location [n,n]
-             * if two numbers n,m are found a location [n,m] is added on 
+             * if two numbers n,m are found a location [n,m] is added on
              * otherwise an error message is printed
-        8b. get the translation from the key "translation" as a linear sequence 
+        8b. get the translation from the key "translation" as a linear sequence
             with extended amino acid alphabet (IUPAC)
-        8c. get a list of possible names 
-            specialized methods for the extraction of the name of tRNA, rRNA, proteins, 
-            and origins are applied on certain values (of key,value pairs) depending 
-            on the feature type: 
+        8c. get a list of possible names
+            specialized methods for the extraction of the name of tRNA, rRNA, proteins,
+            and origins are applied on certain values (of key,value pairs) depending
+            on the feature type:
             - qualifier key "gene" or "product" and feature type
               * feature type is "tRNA" or "gene"  -> tRNA function
               * feature type is "rRNA" or "gene"  -> rRNA function
               * feature type is "CDS" or "gene"  -> protein function
             - qualifier key "standard_name", "note", or "direction"
               * feature type either "rep_origin", "D-loop", "misc_feature"
-            each function checks a list of regular expressions. if one matches the 
+            each function checks a list of regular expressions. if one matches the
             corresponding name is appended to a list of possible names of the feature.
-            - if the list has length 0 
-              * if feature type is "rep_origin" or "D-loop" 
+            - if the list has length 0
+              * if feature type is "rep_origin" or "D-loop"
                 -> OH is returned if strand is +1 and OL if it is -1
               * else None is returned
             - if the list is longer than 1 None is returned
             - if the list has length 1
-              - if the name is L or S it is tries to parse the anticodon 
+              - if the name is L or S it is tries to parse the anticodon
                 from the feature to distinguish L1, L2, S1, S2
-              the name is returned 
+              the name is returned
         8d. depending on the determined name the feature type is determined
         8e. if the feature part name could be determined  then the parts (all determined
             locations) are appended to the list of features as follows:
-            - all previously added features of the same name are checked 
-            i) if there is a feature which is included in the new feature then the 
-              new feature is not added to the list (idea: we take the parts of the 
+            - all previously added features of the same name are checked
+            i) if there is a feature which is included in the new feature then the
+              new feature is not added to the list (idea: we take the parts of the
               features, instead of the complete one)
             ii) if there is a feature which is included the new one then the feature
-              is deleted (and the new feature might be appended depending on 
-               the following checks) 
-            if all checks are done and i) never applied then the feature is added 
+              is deleted (and the new feature might be appended depending on
+               the following checks)
+            if all checks are done and i) never applied then the feature is added
         """
         gb.__init__(self)
 
@@ -274,13 +277,13 @@ class gbfromfile(gb):
 
         try:
             self.comment = record.annotations['comment']
-        except:
+        except Exception:
             self.comment = ""
 
         self.data_file_division = record.annotations['data_file_division']
         try:
             self.date = record.annotations['date']
-        except:
+        except Exception:
             self.date = ""
 
         self.references = record.annotations['references']
@@ -298,7 +301,7 @@ class gbfromfile(gb):
         rRNAs = set()
         for f in record.features:
             name = self._parse_feature_name(f, 1, None)
-            if name == None or (not name in ["12S", "15S", "16S", "21S", "23S"]):
+            if name is None or (name not in ["12S", "15S", "16S", "21S", "23S"]):
                 continue
             rRNAs.add(name)
 #         print "rRNAs", rRNAs
@@ -364,7 +367,7 @@ class gbfromfile(gb):
                 # print "->", "name: ", name, tpe, strand, start, stop
 
                 # ignore features if name or type could not be determined
-                if name == None or tpe == None:
+                if name is None or tpe is None:
                     continue
 
 #                # ignore protein (related) features which are not CDS
@@ -373,7 +376,7 @@ class gbfromfile(gb):
 #                    continue
 
                 if i == 0 or tpe == "intron":
-                    if not name in _cpymap:
+                    if name not in _cpymap:
                         _cpymap[name] = 0
                     else:
                         _cpymap[name] += 1
@@ -386,7 +389,7 @@ class gbfromfile(gb):
 #                 number = self._parse_number( f )
                 # print number
                 # set the part number for multi part features
-#                 if number != None:
+#                 if number is not None:
 #                     part = number
                 if tpe != "intron" and len(loc) > 1:
                     part = i
@@ -395,7 +398,7 @@ class gbfromfile(gb):
 
                 # set the translation for the first part of a feature
                 # otherwise the translation might be reported multiple times
-                if part == None or part == 0:
+                if part is None or part == 0:
                     translation = self._parse_translation(f)
                 else:
                     translation = None
@@ -424,9 +427,9 @@ class gbfromfile(gb):
             copymap = {}
             if len(copies) == 0:
                 raise Exception("parser error 0 copies of a gene")
-            elif len(copies) == 1 and copies[0] == None:
+            elif len(copies) == 1 and copies[0] is None:
                 continue
-            elif len(copies) == 1 and copies[0] != None:
+            elif len(copies) == 1 and copies[0] is not None:
                 copymap[copies[0]] = None
             else:
                 nc = 0
@@ -445,7 +448,7 @@ class gbfromfile(gb):
                 # else:
                 #    print nf, "==", self.features[-1]
 
-            # if name == None:
+            # if name is None:
             #    if f.key in ["CDS","gene","tRNA"]:
             #        print f
             # print name, tpe
@@ -462,12 +465,12 @@ class gbfromfile(gb):
 
     def _add_smaller_feature(self, nf):
         """
-        add a feature: 
-        - the feature is added if it does not include feature with the same 
-          name and strand 
+        add a feature:
+        - the feature is added if it does not include feature with the same
+          name and strand
         - features that include the new feature are deleted
 
-        the feature will be inserted such that the list of features is sorted in increasing order (by start positions) 
+        the feature will be inserted such that the list of features is sorted in increasing order (by start positions)
         """
 
 #        print "add", nf
@@ -489,15 +492,15 @@ class gbfromfile(gb):
             cap, cup = self.features[i].capcup(nf, self.circular, self.size)
             # features[i] included in nf
             # => nf will not be inserted
-            if cap == self.features[i].length( self.circular, self.size ) and \
-                    cup == nf.length(self.circular, self.size):
+            if (cap == self.features[i].length(self.circular, self.size)
+                    and cup == nf.length(self.circular, self.size)):
                 #                print nf, "includes", self.features[i]
                 return
 
             # nf included in features[i]
             # => features[i] will be deleted
-            if cap == nf.length( self.circular, self.size ) and \
-                    cup == self.features[i].length(self.circular, self.size):
+            if (cap == nf.length(self.circular, self.size)
+                    and cup == self.features[i].length(self.circular, self.size)):
                 #                print self.features[i], "includes", nf
                 del self.features[i]
                 continue
@@ -545,34 +548,34 @@ class gbfromfile(gb):
             # special treatment of ORFs. if an ORF and is completely included
             # or includes completely another feature. then remove the orf.
             # applies to potential new features and already present features
-            elif nf.name.startswith( "orf" ) and \
-                not self.features[i].name.startswith( "orf" ) and \
-                (cap == nf.length(self.circular, self.size) or
-                 cup == nf.length(self.circular, self.size)):
+            elif (nf.name.startswith("orf")
+                    and not self.features[i].name.startswith("orf")
+                    and (cap == nf.length(self.circular, self.size)
+                        or cup == nf.length(self.circular, self.size))):
                 # print "discarded", nf, "for", self.features[i]
                 return
-            elif self.features[i].name.startswith( "orf" ) and \
-                not nf.name.startswith( "orf" ) and \
-                (cap == self.features[i].length(self.circular, self.size) or
-                 cup == self.features[i].length(self.circular, self.size)):
+            elif (self.features[i].name.startswith("orf")
+                    and not nf.name.startswith("orf")
+                    and (cap == self.features[i].length(self.circular, self.size)
+                        or cup == self.features[i].length(self.circular, self.size))):
                 # print "discarding", self.features[i], "for", nf
                 del self.features[i]
                 continue
 
             # if the new feature is (truly) included in feature[i]
             # => discard the new feature (strategy is to take the parts)
-            elif nf.name == self.features[i].name and \
-                    cap == nf.length( self.circular, self.size ) and \
-                    cup == self.features[i].length(self.circular, self.size):
+            elif (nf.name == self.features[i].name
+                    and cap == nf.length(self.circular, self.size)
+                    and cup == self.features[i].length(self.circular, self.size)):
                 # logging.warn( "discarding %s for %s" % ( self.features[i], nf ) )
                 del self.features[i]
                 continue
 
             # else if feature[i] is truly included in the new feature
             # => discard feature[i] (i.e. delete it and restart current iteration)
-            elif nf.name == self.features[i].name and \
-                    cap == self.features[i].length( self.circular, self.size ) and \
-                    cup == nf.length(self.circular, self.size):
+            elif (nf.name == self.features[i].name
+                    and cap == self.features[i].length(self.circular, self.size)
+                    and cup == nf.length(self.circular, self.size)):
                 # logging.warn( "discarding %s for %s" % ( nf, self.features[i] ) )
                 return
 
@@ -606,10 +609,10 @@ class gbfromfile(gb):
 
         try:
             self.version = annotations['sequence_version']
-        except:
+        except KeyError:
             self.version = -1
 #        m = re.match( "^([\w]{2}_{0,1}[\d]+)\.(\d+)$", version )
-#        if m != None:
+#        if m is not None:
 #            if m.group( 1 ) != self.accession:
 #                sys.stderr.write( "error: accession in version string (%s) does not match accession (%s)\n" % ( version, self.accession ) )
 #                #sys.exit()
@@ -630,15 +633,15 @@ class gbfromfile(gb):
         v = v.upper()
 
         m = re.search(
-            "POS:(?P<comp>COMPLEMENT){0,1}[\(]{0,1}(?P<start>[\d]+)\.\.(?P<end>[\d]+)[\)]{0,1}", v)
-        if m != None:
+            r"POS:(?P<comp>COMPLEMENT){0,1}[\(]{0,1}(?P<start>[\d]+)\.\.(?P<end>[\d]+)[\)]{0,1}", v)
+        if m is not None:
             d = m.groupdict()
             # print m.re.pattern, d
 
             s = int(d["start"]) - 1
             e = int(d["end"]) - 1
 
-            if not ((d["comp"] == None and strand == 1) or (d["comp"] == "COMPLEMENT" and strand == -1)):
+            if not ((d["comp"] is None and strand == 1) or (d["comp"] == "COMPLEMENT" and strand == -1)):
                 logging.warn("%s anticodon strand differs from feature strand %d %s" % (
                     self.accession, strand, v))
 
@@ -651,7 +654,7 @@ class gbfromfile(gb):
                 pass
 
 #        m = re.match( "ANTICODON: ([U%s]{3})" % Data.IUPACData.ambiguous_dna_letters, v )
-#        if m != None:
+#        if m is not None:
 #            # seq = sequence(m.group(1), IUPAC.ambiguous_rna, circular=False).reverse_complement()
 # #            print m.re.pattern
 #            try:
@@ -661,8 +664,8 @@ class gbfromfile(gb):
 #                pass
 
         m = re.match(
-            "^ANTICODON[ :\s]{1,2}([U%s]{3}).*" % Data.IUPACData.ambiguous_dna_letters, v)
-        if m != None:
+            r"^ANTICODON[ :\s]{1,2}([U%s]{3}).*" % Data.IUPACData.ambiguous_dna_letters, v)
+        if m is not None:
             # seq = sequence(m.group(1), IUPAC.ambiguous_rna, circular=False).reverse_complement()
             #            print m.re.pattern
             try:
@@ -672,38 +675,37 @@ class gbfromfile(gb):
                 pass
 
         nam = unify.unify_name_trna(v, self.transl_table)[0]
-        if cdn != None and nam != None:
+        if cdn is not None and nam is not None:
             cdn = unify.unify_name_trna(v, self.transl_table)[1]
 #            m = re.search( "\(([U%s]{3})\)" % Data.IUPACData.ambiguous_dna_letters, v )
-#            if m != None:
+#            if m is not None:
 #                try:
 #                    cdn = codon( m.group( 1 ), "anticodon" )
 #                except CodonError:
 #                    pass
 
-        if cdn != None and nam == None:
+        if cdn is not None and nam is None:
             return cdn
-        elif cdn != None and nam != None:
+        elif cdn is not None and nam is not None:
             aa = cdn.get_aa(self.transl_table)
             # print cdn, aa, nam
-            if aa != None and nam.startswith("trn" + aa[0]):
+            if aa is not None and nam.startswith("trn" + aa[0]):
                 # print "ACDN MATCH"
                 return cdn
         else:
             return None
 
-
 #    def _parse_codon_from_product( self, v ):
 #        m = re.search( "\(([U%s]{3})\)" % Data.IUPACData.ambiguous_dna_letters, v )
-#        if m == None:
+#        if m is None:
 #            return None
 #        else:
-# #            print "->", m.group( 1 )
+#         #    print "->", m.group( 1 )
 #            return codon( m.group( 1 ), "codon" )
 
     def _parse_codon_recognized(self, v, strand):
         """
-        try to get a codon from value 
+        try to get a codon from value
         return anticodon (initialized as codon)
         """
 
@@ -713,7 +715,7 @@ class gbfromfile(gb):
         v = v.upper()
 
         m = re.match("^([U%s]{3})$" % Data.IUPACData.ambiguous_dna_letters, v)
-        if m != None:
+        if m is not None:
             try:
                 cdn = codon(v, "codon")
             except CodonError:
@@ -721,8 +723,8 @@ class gbfromfile(gb):
                 pass
 
         m = re.match(
-            "^CODONS? RECOGN[IZ]{2}ED[\s:]+([U%s]{3}$)" % Data.IUPACData.ambiguous_dna_letters, v)
-        if m != None:
+            r"^CODONS? RECOGN[IZ]{2}ED[\s:]+([U%s]{3}$)" % Data.IUPACData.ambiguous_dna_letters, v)
+        if m is not None:
             # s =
             # print "CR %s" %(s)
             try:
@@ -732,20 +734,20 @@ class gbfromfile(gb):
                 pass
 
         nam = unify.unify_name_trna(v, self.transl_table)[0]
-        if cdn != None and nam != None:
+        if cdn is not None and nam is not None:
             cdn = unify.unify_name_trna(v, self.transl_table)[1]
 #            m = re.search( "\(([U%s]{3})\)" % Data.IUPACData.ambiguous_dna_letters, v )
-#            if m != None:
+#            if m is not None:
 #                try:
 #                    cdn = codon( m.group( 1 ), "codon" )
 #                except CodonError:
 #                    pass
 
-        if cdn != None and nam == None:
+        if cdn is not None and nam is None:
             return cdn
-        elif cdn != None and nam != None:
+        elif cdn is not None and nam is not None:
             aa = cdn.get_aa(self.transl_table)
-            if aa != None and nam.startswith("trn" + aa[0]):
+            if aa is not None and nam.startswith("trn" + aa[0]):
                 return cdn
         else:
             return None
@@ -753,7 +755,7 @@ class gbfromfile(gb):
     def _parse_circular(self, rt):
         """
         parse circularity from residuetype string
-        \param rt residuetype string
+        param rt residuetype string
         """
 
         if rt.endswith("circular"):
@@ -771,7 +773,7 @@ class gbfromfile(gb):
         try to parse the anticodon from a feature
         /anticodon=/codon_recognized
         @param f the feature
-        @param strand the strand 
+        @param strand the strand
         @param unambiguous prefer unambiguous anticodons
         """
 
@@ -788,7 +790,7 @@ class gbfromfile(gb):
             if q not in ["anticodon", "codon_recognized"] and len(codons) > 0:
                 break
 
-            if not q in f.qualifiers:
+            if q not in f.qualifiers:
                 continue
 
             for x in f.qualifiers[q]:
@@ -807,7 +809,7 @@ class gbfromfile(gb):
                     codons.append(c)
                     c = self._parse_codon_recognized(x, strand)
                     codons.append(c)
-                codons = [x for x in codons if x != None]
+                codons = [x for x in codons if x is not None]
 
         uacodons = []
         for c in codons:
@@ -849,7 +851,7 @@ class gbfromfile(gb):
 
     def _parse_feature_locations(self, feature):
         """
-        parse location(s) from subfeatures 
+        parse location(s) from subfeatures
         @return list of locations, i.e. list of triples (start, stop, strand)
         """
 
@@ -857,7 +859,7 @@ class gbfromfile(gb):
         loc = []
 
         for f in feature.location.parts:
-            if f.strand == None or f.strand >= 0:
+            if f.strand is None or f.strand >= 0:
                 strand = 1
             else:
                 strand = -1
@@ -873,14 +875,14 @@ class gbfromfile(gb):
         try to determine the name of a feature
         for trna, rrna, and genes try to guess the name from the gene or product qualifier
 
-        in order to get the origins additionally: 
+        in order to get the origins additionally:
         for rep_origin, D-loop, misc_feature try to guess the name from standard_name, note, direction"
 
         if there are several different guesses -> return None
         otherwise assign OH/OL to an origin feature
         and try to get the number of Leu/Ser tRNAs
 
-        if rRNAs == None only potential rRNA features are considered        
+        if rRNAs is None only potential rRNA features are considered
 
         @param[in] f the feature
         @param[in] strand the strand of the feature
@@ -892,17 +894,17 @@ class gbfromfile(gb):
         for q in f.qualifiers:
             for x in f.qualifiers[q]:
                 if q in ["gene", "product", "note"]:
-                    if rRNAs != None and f.type in ["tRNA", "gene"]:
+                    if rRNAs is not None and f.type in ["tRNA", "gene"]:
                         s.add(unify.unify_name_trna(x, self.transl_table)[0])
                     if f.type in ["rRNA", "gene"]:
                         s.add(unify.unify_name_rrna(x, rRNAs))
                     # Note gene is currently not parsed for proteins otherwise
                     # the exons are not reported
-                    if rRNAs != None and f.type in ["CDS"]:
+                    if rRNAs is not None and f.type in ["CDS"]:
                         s.add(unify.unify_name_protein(x))
                         s.add(unify.unify_name_orf(x))
                 if q in ["standard_name", "note", "direction", "product", "gene"]:
-                    if rRNAs != None and f.type in ["rep_origin", "D-loop", "misc_feature", "stem_loop", "repeat_region", "misc_signal"]:
+                    if rRNAs is not None and f.type in ["rep_origin", "D-loop", "misc_feature", "stem_loop", "repeat_region", "misc_signal"]:
                         if f.type == "rep_origin":
                             s.add(unify.unify_name_origin(x, "OL", True))
                         elif f.type == "D-loop":
@@ -911,13 +913,13 @@ class gbfromfile(gb):
                             s.add(unify.unify_name_origin(x, "OH", False))
 #                         qal.add( x )
                 if q in ["note"]:
-                    if rRNAs != None and f.type == "intron":
+                    if rRNAs is not None and f.type == "intron":
                         s.add(unify.unify_name_intron(x, "intron"))
 
         s.discard(None)
         s = list(s)
 
-        if rRNAs != None and len(s) == 0:
+        if rRNAs is not None and len(s) == 0:
             if f.type == "D-loop":
                 s.append("OH")
             elif f.type == "rep_origin":
@@ -950,9 +952,9 @@ class gbfromfile(gb):
             s = ["rrnS"]
 
         if len(s) == 2:
-            if "giy" in s and not "lagli" in s:
+            if "giy" in s and "lagli" not in s:
                 s = ["giy"]
-            elif "lagli" in s and not "giy" in s:
+            elif "lagli" in s and "giy" not in s:
                 s = ["lagli"]
 
         # check if there is exactly one element in s
@@ -1001,7 +1003,7 @@ class gbfromfile(gb):
         # if tpe == "tRNA":
         #
         #    for c in codons:
-        #        if c != None:
+        #        if c is not None:
         #            s += c.get_aa(self.transl_table)
 
         # rint self.accession
@@ -1020,7 +1022,7 @@ class gbfromfile(gb):
 
     def _parse_names(self, annotations):
         """
-        parse the name, common name, and completeness from the definition 
+        parse the name, common name, and completeness from the definition
         organism and source lines
         """
 
@@ -1032,19 +1034,19 @@ class gbfromfile(gb):
         # take organism as name
         try:
             self.name = annotations["organism"]
-        except:
+        except Exception:
             raise Exception("NoName", str(annotations))
 
         # try to get common name from source
 
-        n = self.name.replace("(", "\(").replace(")", "\)")
+        n = self.name.replace("(", "\\(").replace(")", "\\)")
 
         if "source" in annotations:
             m = re.match(
-                'mitochondrion %s(?P<commonname> \(.*\)){0,1}$' % n, annotations["source"])
+                r'mitochondrion %s(?P<commonname> \(.*\)){0,1}$' % n, annotations["source"])
 
-            if m != None:
-                if m.group('commonname') != None:
+            if m is not None:
+                if m.group('commonname') is not None:
                     self.commonname = m.group('commonname')[2:-1]
                 else:
                     self.commonname = ""
@@ -1059,7 +1061,7 @@ class gbfromfile(gb):
 #                continue
 #
 #            m = re.match( '(mitochondrion ){0,1}(?P<name>.*)(?P<commonname> \([^(]*\)){0,1}$', a )
-#            if m == None:
+#            if m is None:
 #                raise Exception( "Malformed", i, annotations[i] )
 #
 #            if self.name == "" or self.name == m.group( 'name' ):
@@ -1067,7 +1069,7 @@ class gbfromfile(gb):
 #            else:
 #                raise Exception( "Name mismatch in source/organism", self.name, m.group( 'name' ) )
 #
-#            if m.group( 'commonname' ) != None:
+#            if m.group( 'commonname' ) is not None:
 #                cn = m.group( 'commonname' )[2:-1]
 #                if self.commonname == "" or self.commonname == cn:
 #                    self.commonname = cn
@@ -1082,13 +1084,13 @@ class gbfromfile(gb):
         """
         try:
             return int(feature.qualifiers['number'][0]) - 1
-        except:
+        except Exception:
             return None
 
     def _parse_source(self, feature):
         """
         parse entries from the source feature
-        currently this is the taxid and strain 
+        currently this is the taxid and strain
         @param[in] feature the source feature
         @return nothing
         """
@@ -1097,19 +1099,19 @@ class gbfromfile(gb):
 #        print "location", feature.location
         try:
             dbxref = feature.qualifiers['db_xref'][0]
-        except:
+        except KeyError:
             dbxref = ""
 
         if dbxref.startswith("taxon:"):
             self.taxid = int(dbxref[6:])
 
-        if self.taxid == None:
+        if self.taxid is None:
             sys.stderr.write(
                 "warning: %s could not determine taxid\n" % self.accession)
 
         try:
             self.strain = feature.qualifiers['strain'][0]
-        except:
+        except KeyError:
             self.strain = ""
 
     def _parse_translation(self, feature):
@@ -1146,7 +1148,7 @@ class gbfromfile(gb):
         else:
             self.transl_table = int(list(s)[0])
 
-        if not self.transl_table in Data.CodonTable.unambiguous_dna_by_id:
+        if self.transl_table not in Data.CodonTable.unambiguous_dna_by_id:
             logging.warning("warning (%s) has unknown translation table %d" % (
                 self.accession, self.transl_table))
             self.transl_table = 1
