@@ -269,8 +269,8 @@ def appendlocalfeature(lokalHits, lname, rrnafeat, featurelist, seqlen,
             # determine the corresponding extended gap
             # - sort by overlap
             # - take the one with the largest overlap
-            egaps.sort(key=lambda l, r: feature.cap(
-                l, r, globalanfang, globalende, circular, seqlen), reverse=True)
+            egaps.sort(key=lambda left, right: feature.cap(
+                left, right, globalanfang, globalende, circular, seqlen), reverse=True)
             if feature.cap(egaps[0][0], egaps[0][1], globalanfang, globalende, circular, seqlen) > 0:
                 anfang = egaps[0][0]
                 ende = egaps[0][1]
