@@ -149,7 +149,7 @@ def cmsearch(seqfile, outpath, code, refdir, evalue, sensitive, length, gl=True,
 #         print( " ".join( cmsargs + cmsargssen + [m, seqfile] ) )
         proc = subprocess.Popen(cmsargs + cmsargssen + [m, seqfile],
                                 stdout=subprocess.PIPE,
-                                stderr=subprocess.PIPE, universal_newlines=True)
+                                stderr=subprocess.PIPE)
         out, err = proc.communicate()
 
         if proc.returncode != 0 or len(err) > 0:
@@ -157,9 +157,9 @@ def cmsearch(seqfile, outpath, code, refdir, evalue, sensitive, length, gl=True,
             logging.error("for\n%s" %
                           (" ".join(cmsargs + cmsargssen + [m, seqfile])))
 
-            raise InfernalException(" ".join(" ".join(cmsargs + cmsargssen + [m, seqfile]), proc.returncode, err))
+            raise InfernalException(" ".join(cmsargs + cmsargssen + [m, seqfile]), proc.returncode, err)
         else:
-            f = open(outfile, "w")
+            f = open(outfile, "wb")
             f.write(out)
             f.close()
 
@@ -174,7 +174,7 @@ def cmsearch(seqfile, outpath, code, refdir, evalue, sensitive, length, gl=True,
         logging.debug(" ".join(mitfiargs + mitfi_spec[t]))
         proc = subprocess.Popen(mitfiargs + mitfi_spec[t],
                                 stdout=subprocess.PIPE,
-                                stderr=subprocess.PIPE, universal_newlines=True)
+                                stderr=subprocess.PIPE)
         out, err = proc.communicate()
 
         if proc.returncode != 0 or len(err) > 0:
@@ -183,7 +183,7 @@ def cmsearch(seqfile, outpath, code, refdir, evalue, sensitive, length, gl=True,
             raise InfernalException(" ".join(mitfiargs + mitfi_spec[t]), proc.returncode, err)
         else:
             f = open("%s/%s_%sout.nc" %
-                     (outpath, os.path.basename(seqfile), t), "w")
+                     (outpath, os.path.basename(seqfile), t), "wb")
             f.write(out)
             f.close()
 
@@ -195,7 +195,7 @@ def cmsearch(seqfile, outpath, code, refdir, evalue, sensitive, length, gl=True,
 #         logging.debug( " ".join( mitfiargs + mitfitRNA ) )
 #         proc = subprocess.Popen( mitfiargs + mitfitRNA, \
 #                                      stdout = subprocess.PIPE, \
-#                                      stderr = subprocess.PIPE, universal_newlines=True )
+#                                      stderr = subprocess.PIPE )
 #         out, err = proc.communicate()
 #         if proc.returncode != 0 or len( err ) > 0:
 #             logging.error( "mitfi exception\n%s" % err )
@@ -211,7 +211,7 @@ def cmsearch(seqfile, outpath, code, refdir, evalue, sensitive, length, gl=True,
 #         logging.debug( " ".join( mitfiargs + mitfirRNA ) )
 #         proc = subprocess.Popen( mitfiargs + mitfirRNA , \
 #                                      stdout = subprocess.PIPE, \
-#                                      stderr = subprocess.PIPE, universal_newlines=True)
+#                                      stderr = subprocess.PIPE )
 #         out, err = proc.communicate()
 #         if proc.returncode != 0 or len( err ) > 0:
 #             logging.error( "mitfi exception\n%s" % err )
@@ -260,7 +260,7 @@ def cmrealign(sequence, rRNA, refdir):
 
     logging.debug(" ".join(args))
     proc = subprocess.Popen(
-        args, stdout=subprocess.PIPE, stderr=subprocess.PIPE, universal_newlines=True)
+        args, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
     out, err = proc.communicate()
     if proc.returncode != 0 or len(err) > 0:
         logging.error("cmalign exception\n%s" % err)
@@ -276,7 +276,7 @@ def cmrealign(sequence, rRNA, refdir):
     # improve structure
     proc = subprocess.Popen(["java", "-jar", mitfiimppath, tdir, "%s/cmrealign.stk" % (tdir)],
                             stdout=subprocess.PIPE,
-                            stderr=subprocess.PIPE, universal_newlines=True)
+                            stderr=subprocess.PIPE)
     out, err = proc.communicate()
     if proc.returncode != 0 or len(err) > 0:
         logging.error("improve_infernal_structure exception\n%s" % err)
