@@ -1,76 +1,73 @@
 '''
 @author: M. Bernt
 
-This is a confidential release. Do not redistribute without 
-permission of the author (bernt@informatik.uni-leipzig.de).
-
 This module provides some useful things for mitochondrial genomes
 '''
 
 # tRNAs
 # - metazoa default set
-metazoa_trna = ["trnA", "trnR", "trnN", "trnD", "trnC", "trnQ", "trnE", \
-                "trnG", "trnH", "trnI", "trnL1", "trnL2", "trnK", \
-                "trnM", "trnF", "trnP", "trnS1", "trnS2", "trnT", \
+metazoa_trna = ["trnA", "trnR", "trnN", "trnD", "trnC", "trnQ", "trnE",
+                "trnG", "trnH", "trnI", "trnL1", "trnL2", "trnK",
+                "trnM", "trnF", "trnP", "trnS1", "trnS2", "trnT",
                 "trnW", "trnY", "trnV"]
 # some other tRNA names
 other_trna = ["trnL", "trnS", "trnX", "trnZ"]
 trna = metazoa_trna + other_trna
 
 # list of tRNA names
-trnamap = {'ALA':'trnA', 'ARG':'trnR', 'ASN':'trnN', 'ASP':'trnD', 'CYS':'trnC', \
-           'GLN':'trnQ', 'GLU':'trnE', 'GLY':'trnG', 'HIS':'trnH', 'ILE':'trnI', \
-           'LEU':'trnL', 'LEU1':'trnL1', 'LEU2':'trnL2', 'LYS':'trnK', \
-           'MET':'trnM', 'PHE':'trnF', 'PRO':'trnP', 'SER':'trnS', \
-           'SER1':'trnS1', 'SER2':'trnS2', 'THR':'trnT', 'TRP':'trnW', 'TYR':'trnY', \
-           'VAL':'trnV'}
+trnamap = {'ALA': 'trnA', 'ARG': 'trnR', 'ASN': 'trnN', 'ASP': 'trnD', 'CYS': 'trnC',
+           'GLN': 'trnQ', 'GLU': 'trnE', 'GLY': 'trnG', 'HIS': 'trnH', 'ILE': 'trnI',
+           'LEU': 'trnL', 'LEU1': 'trnL1', 'LEU2': 'trnL2', 'LYS': 'trnK',
+           'MET': 'trnM', 'PHE': 'trnF', 'PRO': 'trnP', 'SER': 'trnS',
+           'SER1': 'trnS1', 'SER2': 'trnS2', 'THR': 'trnT', 'TRP': 'trnW', 'TYR': 'trnY',
+           'VAL': 'trnV'}
 
-def revtrnamap( sname ):
+
+def revtrnamap(sname):
     for lname in trnamap:
-        if sname == trnamap[ lname ]:
+        if sname == trnamap[lname]:
             return lname
     return "UNK"
 
+
 # revtrnamap = lambda smallname:[longname for longname in trnamap if trnamap[longname] == smallname][0]
 
 # list of rRNAs
 metazoa_rrna = ["rrnS", "rrnL"]
 rrna = metazoa_rrna
-rrnamap = {"rrnS":"s", "rrnL":"l"}
+rrnamap = {"rrnS": "s", "rrnL": "l"}
 
 # list of protein coding genes
-metazoa_prot = ['cox1', 'cox2', 'cox3', 'cob', 'atp6', 'atp8', 'nad1', 'nad2', \
+metazoa_prot = ['cox1', 'cox2', 'cox3', 'cob', 'atp6', 'atp8', 'nad1', 'nad2',
                 'nad3', 'nad4', 'nad4l', 'nad5', 'nad6']
-metazoa_other_prot = [ 'atp9', 'msh1', 'mttb', 'dpo', 'rpo', 'lagli']
-fungi_prot = [ 'rps3', 'rps5', 'giy', 'lagli' ]
+metazoa_other_prot = ['atp9', 'msh1', 'mttb', 'dpo', 'rpo', 'lagli']
+fungi_prot = ['rps3', 'rps5', 'giy', 'lagli']
 prot = metazoa_prot + metazoa_other_prot + fungi_prot
 
-revprot = {"cox1":"cytochrome c oxidase subunit 1", \
-           "cox2":"cytochrome c oxidase subunit 2", \
-           "cox3":"cytochrome c oxidase subunit 3", \
-           "cob":"cytochrome b", \
-           "nad1":"NADH dehydrogenase subunit 1", \
-           "nad2":"NADH dehydrogenase subunit 2", \
-           "nad3":"NADH dehydrogenase subunit 3", \
-           "nad4":"NADH dehydrogenase subunit 4", \
-           "nad4l":"NADH dehydrogenase subunit 4L", \
-           "nad5":"NADH dehydrogenase subunit 5", \
-           "nad6":"NADH dehydrogenase subunit 6", \
-           "atp6":"ATP synthase F0 subunit 6", \
-           "atp8":"ATP synthase F0 subunit 8", \
-           "atp9":"ATP synthase F0 subunit 9", \
-           "msh1": "MutS-like protein", \
-           "mttb": "SecY-independent transporter protein", \
-           "dpo": "DNA polymerase", \
-           "rpo": "RNA polymerase", \
-           "lagli": "LAGLIDADG endonuclease", \
-           "giy":"GIY endonuclease", \
-           "rps3":"Ribosomal protein S3", \
-           "rps5":"Ribosomal protein S5", \
+revprot = {"cox1": "cytochrome c oxidase subunit 1",
+           "cox2": "cytochrome c oxidase subunit 2",
+           "cox3": "cytochrome c oxidase subunit 3",
+           "cob": "cytochrome b",
+           "nad1": "NADH dehydrogenase subunit 1",
+           "nad2": "NADH dehydrogenase subunit 2",
+           "nad3": "NADH dehydrogenase subunit 3",
+           "nad4": "NADH dehydrogenase subunit 4",
+           "nad4l": "NADH dehydrogenase subunit 4L",
+           "nad5": "NADH dehydrogenase subunit 5",
+           "nad6": "NADH dehydrogenase subunit 6",
+           "atp6": "ATP synthase F0 subunit 6",
+           "atp8": "ATP synthase F0 subunit 8",
+           "atp9": "ATP synthase F0 subunit 9",
+           "msh1": "MutS-like protein",
+           "mttb": "SecY-independent transporter protein",
+           "dpo": "DNA polymerase",
+           "rpo": "RNA polymerase",
+           "lagli": "LAGLIDADG endonuclease",
+           "giy": "GIY endonuclease",
+           "rps3": "Ribosomal protein S3",
+           "rps5": "Ribosomal protein S5",
            }
 
-
-
 #        'COX1':'gene', 'COX2':'gene', \
 #        'COX3':'gene', 'ATP6':'gene', 'ATP8':'gene', 'ATP9':'gene', \
 #        'CYTB':'gene', 'ND1':'gene', 'ND2':'gene', 'ND3':'gene', \
@@ -100,7 +97,8 @@ for t in rep_origin:
 for t in intron:
     types[t] = "intron"
 
-def type_from_name( name ):
+
+def type_from_name(name):
     if name in types:
         return types[name]
 
@@ -112,14 +110,16 @@ def type_from_name( name ):
 
     return None
 
-metazoa_default = set( metazoa_prot )
-metazoa_default.update( set( metazoa_rrna ) )
-metazoa_default.update( set( metazoa_trna ) )
-metazoa_default.update( set( ["OH", "OL"] ) )
 
-def is_metazoa_default( name ):
+metazoa_default = set(metazoa_prot)
+metazoa_default.update(set(metazoa_rrna))
+metazoa_default.update(set(metazoa_trna))
+metazoa_default.update(set(["OH", "OL"]))
+
+
+def is_metazoa_default(name):
     """
-    check if a given gene is in the metazoa standard genes 
+    check if a given gene is in the metazoa standard genes
     @param name the name of the gene
     @return true iff its is a default gene
     """
@@ -128,6 +128,8 @@ def is_metazoa_default( name ):
         return True
     else:
         return False
+
+
 # types = {\
 #        'rrnS':'rRNA', 'rrnL':'rRNA', 'cox1':'gene', 'cox2':'gene', \
 #        'cox3':'gene', 'atp6':'gene', 'atp8':'gene', 'atp9':'gene', \
@@ -142,4 +144,3 @@ def is_metazoa_default( name ):
 
 # list of all genes
 gene = trna + rrna + prot
-
