@@ -113,7 +113,7 @@ class mitofromfile(gb):
                 nf.copy = data["copy"]
                 nf.part = data["part"]
             else:
-                nf = feature(name=data["name"], type=data["type"], method=data["method"],
+                nf = feature(name=data["name"], tpe=data["type"], method=data["method"],
                           start=data["start"], stop=data["stop"],
                           strand=data["strand"], score=data["score"], anticodon=data["anticodon"],
                           copy=data["copy"], part=data["part"])
