@@ -366,7 +366,7 @@ def getrevision():
 
     try:
         revision = None
-        _p = subprocess.Popen(["svn", "info"], stdout=subprocess.PIPE, universal_newlines=True)
+        _p = subprocess.Popen(["svn", "info"], stdout=subprocess.PIPE)
         svninfo = _p.communicate()[0]
         for line in svninfo.split("\n"):
             if line.startswith("Revision"):
@@ -390,7 +390,7 @@ def getrevisiondate():
 
     try:
         revision = None
-        _p = subprocess.Popen(["svn", "info"], stdout=subprocess.PIPE, universal_newlines=True)
+        _p = subprocess.Popen(["svn", "info"], stdout=subprocess.PIPE)
         svninfo = _p.communicate()[0]
         for line in svninfo.split("\n"):
             if line.startswith("Last Changed Date"):
