@@ -72,7 +72,7 @@ def hmmscan_call(seqfile, gene, dbfile, tmpDir):
            "--noali", "--domtblout", outFile, dbfile, seqfile]
     logging.debug("%s" % (" ".join(cmd)))
     proc = subprocess.Popen(cmd, stdout=subprocess.PIPE,
-                            stderr=subprocess.PIPE, universal_newlines=True)
+                            stderr=subprocess.PIPE)
     out, err = proc.communicate()
 
     if proc.returncode != 0 or len(err) > 0:
