@@ -1,15 +1,13 @@
 '''
 @author: M. Bernt
-
-This is a confidential release. Do not redistribute without 
-permission of the author (bernt@informatik.uni-leipzig.de).
 '''
 
-from Bio import Alphabet
-from Bio import Data
+from Bio import (
+    Alphabet,
+    Data,
+)
 
-from ..sequence import sequence
-from ..rna.vienna import RNAeval
+from mitos.sequence import sequence
 
 trna_nameaamap = {'Ala': 'A', 'Arg': 'R', 'Asn': 'N', 'Asp': 'D', 'Cys': 'C', 'Glu': 'E', 'Gln': 'Q', 'Gly': 'G',
                   'His': 'H', 'Ile': 'I', 'Leu': 'L', 'Lys': 'K', 'Met': 'M', 'Phe': 'F', 'Pro': 'P', 'Ser': 'S', 'Thr': 'T',
@@ -17,7 +15,6 @@ trna_nameaamap = {'Ala': 'A', 'Arg': 'R', 'Asn': 'N', 'Asp': 'D', 'Cys': 'C', 'G
 
 
 class CodonError(Exception):
-
     def __init__(self, value):
         self.value = value
 
@@ -40,13 +37,13 @@ class codon(sequence):
         init a codon from codon / anticodon sequence
         a) name==None: set seq and type explicitely
         b) name!=None: given seq and name guess the type
-           in this case tpe will be used as default if the name did 
+           in this case tpe will be used as default if the name did
            not help
 
-        \param seq a D/RNA sequence of length 3 (a string)
-        \param tpe specify if seq is the codon or anticodon 
-        \param name get the type with the help of the name
-        \param transl_table 
+        param seq a D/RNA sequence of length 3 (a string)
+        param tpe specify if seq is the codon or anticodon
+        param name get the type with the help of the name
+        param transl_table
         """
 
         # codon must be of length 3
@@ -57,7 +54,7 @@ class codon(sequence):
         seq = seq.replace("U", "T").replace("u", "t")
 
         # print "codon init", tpe, seq, name
-        if name != None and transl_table != None:
+        if name is not None and transl_table is not None:
 
             # start with the anti codon, since in the trnX(...) format
             # more often the anticodon is given.
@@ -67,7 +64,7 @@ class codon(sequence):
                 c = codon(seq, t)
                 aa = c.get_aa(transl_table)
 #                print c, aa, name
-                if aa != None and name.startswith("trn" + aa):
+                if aa is not None and name.startswith("trn" + aa):
                     tpe = t
 #                    print "GUESS", t, c
                     break
