@@ -267,7 +267,7 @@ def prepareFiles(data, outdir, codss, codin, delinner):
         cmd = ["makeblastdb", "-dbtype", "nucl", "-in", fname]
 
         out, err = subprocess.Popen(cmd, stdout=subprocess.PIPE,
-                                    stderr=subprocess.PIPE, universal_newlines=True).communicate()
+                                    stderr=subprocess.PIPE).communicate()
         if len(err) > 0:
             logging.error("makeblastdb exception\n%s\n%s" %
                           (" ".join(cmd), err))
@@ -279,7 +279,7 @@ def prepareFiles(data, outdir, codss, codin, delinner):
     for fname in glob.glob('%s/*.fas' % (feature_prot_path)):
         cmd = ["makeblastdb", "-dbtype", "prot", "-in", fname]
         out, err = subprocess.Popen(cmd, stdout=subprocess.PIPE,
-                                    stderr=subprocess.PIPE, universal_newlines=True).communicate()
+                                    stderr=subprocess.PIPE).communicate()
         if len(err) > 0:
             logging.error("makeblastdb exception\n%s\n%s" %
                           (" ".join(cmd), err))
@@ -546,7 +546,7 @@ def singleblastx(seqfile, code, outputdir, refdir):
 
         cmd = ["blastx", "-query", seqfile] + param
         logging.debug(" ".join(cmd))
-        proc = subprocess.Popen(cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE, universal_newlines=True)
+        proc = subprocess.Popen(cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
         out, err = proc.communicate()
         if proc.returncode or len(err) > 0:
             logging.error("blastx exception\n%s" % err)
@@ -611,7 +611,7 @@ def singleblastn(seqfile, outputdir, refdir):
 
         cmd = ["blastn", "-query", seqfile] + param
         logging.debug(" ".join(cmd))
-        proc = subprocess.Popen(cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE, universal_newlines=True)
+        proc = subprocess.Popen(cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
         out, err = proc.communicate()
         if proc.returncode or len(err) > 0:
             logging.error("blastn exception\n%s" % err)
