@@ -9,6 +9,7 @@ import json
 import logging
 import os
 import re
+import shutil
 import subprocess
 import sys
 
@@ -175,9 +176,8 @@ def mitos(fastafile, code, ncbicode, best, order, alarab=False,
                        id=fasta[0]["id"], name=fasta[0]["name"], description=fasta[0]["description"])
 
         tmpff = "%s/%s-%s" % (path, os.path.basename(fastafile), str(offset))
-        f = open(tmpff, "w")
-        SeqIO.write(sr, f, "fasta")
-        f.close()
+        with open(tmpff, "w") as f:
+            SeqIO.write(sr, f, "fasta")
 
         fastafiles.append(tmpff)
         offsets.append(offset)
@@ -635,7 +635,7 @@ def mitos(fastafile, code, ncbicode, best, order, alarab=False,
                "%d" % (len(sequence))]
         logging.debug(" ".join(cmd))
         p = subprocess.Popen(
-            cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE, universal_newlines=True)
+            cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
         ret = p.wait()
         if ret != 0:
             stdout, stderr = p.communicate()
@@ -647,7 +647,7 @@ def mitos(fastafile, code, ncbicode, best, order, alarab=False,
                "%s/plots/" % (path)]
         logging.debug(" ".join(cmd))
         p = subprocess.Popen(
-            cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE, universal_newlines=True)
+            cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
         ret = p.wait()
         if ret != 0:
             stdout, stderr = p.communicate()
@@ -661,7 +661,7 @@ def mitos(fastafile, code, ncbicode, best, order, alarab=False,
                "%s/plots/rna.pdf" % (path)]
         logging.debug(" ".join(cmd))
         p = subprocess.Popen(
-            cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE, universal_newlines=True)
+            cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
         ret = p.wait()
         if ret != 0:
             stdout, stderr = p.communicate()
@@ -683,7 +683,8 @@ def mitos(fastafile, code, ncbicode, best, order, alarab=False,
                     (path, f.name, f.start + 1, f.stop + 1))
             RNAplot(f.sequence, f.structure, "%s/plots/%s-%d-%d.svg" %
                     (path, f.name, f.start + 1, f.stop + 1), o="svg")
-
+    for fastafile in fastafiles:
+        os.remove(fastafile)
     return featurelist
 
 
@@ -868,7 +869,7 @@ if __name__ == '__main__':
     group.add_argument("-c", '--code', dest="code", action="store",
                        required=False, type=int, help="the genetic code")
     group.add_argument("-o", '--outdir', dest="outdir", action="store", required=True,
-                       help="the directory where the output is written")
+                       help="the directory where the output is written.")
     group.add_argument("--linear", dest="circular", action="store_false",
                        default=True, help="treat sequence as linear")
     group.add_argument("-r", '--refseqver', dest="refseqver", action="store",
@@ -937,6 +938,8 @@ if __name__ == '__main__':
     group = parser.add_argument_group("debug/misc options")
     group.add_argument(
         "--debug", action="store_true", default=False, help="print debug output")
+    group.add_argument(
+        "--zip", action="store_true", default=False, help="create zip")
     group.add_argument("--json", default=None,
                        help="a JSON file with parameters. then outdir is the only other argument needed.")
     group.add_argument('--version', action='version', version='%(prog)s {version}'.format(version=__version__))
@@ -1018,11 +1021,11 @@ if __name__ == '__main__':
         for d in ["id", "name", "description"]:
             sequences[i][d] = re.sub('[()?|\t]', '_', sequences[i][d])
 
-        tmpf = open("%s/sequence.fas" % odir, "w")
-        sr = SeqRecord(seq=sequences[i]["sequence"], id=sequences[i]["id"],
+        with open("%s/sequence.fas" % odir, "w") as tmpf:
+            sr = SeqRecord(seq=sequences[i]["sequence"], id=sequences[i]["id"],
                        name=sequences[i]["name"], description=sequences[i]["description"])
-        SeqIO.write(sr, tmpf, "fasta")
-        tmpf.close()
+            SeqIO.write(sr, tmpf, "fasta")
+
         # MITOS
         featurelist = mitos("%s/sequence.fas" % odir, args.code, args.ncbicode, args.best,
                             order, args.alarab, odir,
@@ -1041,13 +1044,29 @@ if __name__ == '__main__':
 
         bedfile.bedwriter(featurelist, acc, outfile="%s/result.bed" % odir)
         sequin.sequinwriter(featurelist, acc, outfile="%s/result.seq" % odir)
-        gfffile.gffwriter(featurelist, acc, outfile="%s/result.gff" % odir, mode="w")
+        gfffile.gffwriter(featurelist, acc, len(sequences[i]["sequence"]), outfile="%s/result.gff" % odir, mode="w")
         feature.genorderwriter(featurelist, acc, "%s/result.geneorder" % odir)
         fastawriter(featurelist, sequences[i]["sequence"], None, acc, "fas", outfile="%s/result.fas" % odir)
         fastawriter(featurelist, sequences[i]["sequence"], args.code, acc, "faa", outfile="%s/result.faa" % odir)
 
+        # draw via external programm since reportlab prints
+        # to stderr which should not be visible https://github.com/Distrotech/reportlab/issues/15
+        cmd = ["drawmitos.py",
+            "--input", f"{odir}/result.bed",
+            "--output", f"{odir}/result.png",
+            "--length", str(len(sequences[0]["sequence"]))]
+        logging.debug(" ".join(cmd))
+        p = subprocess.Popen(
+            cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+        ret = p.wait()
+        if ret != 0:
+            stdout, stderr = p.communicate()
+            raise Exception("drawmitos.py returned non zero \n%s\nstdout: %s\nstderr: %s\n" % (
+                " ".join(cmd), stdout, stderr))
+
         # parse fasta header
         sequence = sequences[i]["sequence"]
+        sequence_length = len(sequences[i]["sequence"])
         mis, dup, nst, texc = problems(orderdict["gene"] > 0, orderdict["tRNA"] > 0, orderdict[
                                        "rRNA"] > 0, orderdict["OH"] > 0 or orderdict["OL"] > 0, featurelist, args.circular, sequence, args.code)
         istop = problems_internal_stops(featurelist, sequence, args.code)
@@ -1078,7 +1097,5 @@ if __name__ == '__main__':
         # remove temporary sequence file
         os.remove("%s/sequence.fas" % odir)
 
-
-#     pkl = open("%s/result.pkl" % args.outdir, "w")
-#     cPickle.dump(featurelist, pkl)
-#     pkl.close()
+    if args.zip:
+        shutil.make_archive(os.path.normpath(odir), 'zip', odir)
