@@ -2,21 +2,15 @@
 
 '''
 @author: M. Bernt
-
-This is a confidential release. Do not redistribute without 
-permission of the author (bernt@informatik.uni-leipzig.de).
-
-
-@author: maze
 '''
-from __future__ import print_function
+
+import argparse
+import logging
 import os
 import os.path
-import logging
 
 from mitos.gb import gbfromfile
 
-import argparse
 usage = "search for closest mitogenomes"
 parser = argparse.ArgumentParser(description=usage)
 
@@ -68,12 +62,13 @@ def print_nwk(sid, chld, taxidacc, ndcnt, nmsmap):
     if ac > 1:
         try:
             n = nmsmap[sid]
-        except:
+        except KeyError:
             n = ""
         return "(" + nwk + ")" + n
     else:
         return nwk
 
+
 logging.info("reading names")
 
 # read the taxid name mapping. the two dictionaries nmsmap and taxmap
@@ -81,16 +76,16 @@ logging.info("reading names")
 nmsmap = {}
 taxmap = {}
 nmsdmp = open(args.names)
-for l in nmsdmp.readlines():
-    l = l.split("|")
-    l = [x.strip() for x in l]
-    l[0] = int(l[0])
-    if not l[0] in nmsmap:
+for line in nmsdmp.readlines():
+    line = line.split("|")
+    line = [x.strip() for x in line]
+    line[0] = int(line[0])
+    if not line[0] in nmsmap:
         #        stderr.write("duplicate entry in names.dmp: \n\t%d %s\t%s\n" %(l[0], l[1],nmsmap[l[0]] ))
         #    else:
-        nmsmap[l[0]] = l[1]
+        nmsmap[line[0]] = line[1]
 
-    taxmap[l[1]] = l[0]
+    taxmap[line[1]] = line[0]
 nmsdmp.close()
 
 logging.info("reading tree")
@@ -100,44 +95,44 @@ prnt = {}
 
 rankmap = {}
 ndsdmp = open(args.nodes)
-for l in ndsdmp.readlines():
-    l = l.split("|")
-    l = [x.strip() for x in l]
-    l[0] = int(l[0])
-    l[1] = int(l[1])
+for line in ndsdmp.readlines():
+    line = line.split("|")
+    line = [x.strip() for x in line]
+    line[0] = int(line[0])
+    line[1] = int(line[1])
 
-    if l[1] != l[0]:
+    if line[1] != line[0]:
         try:
-            chld[l[1]].append(l[0])
-        except:
-            chld[l[1]] = [l[0]]
-        prnt[l[0]] = l[1]
-    elif l[0] != 1 or l[1] != 1:
-        logging.error("cycle detected: \t%d \t%d" % (l[0], l[1]))
+            chld[line[1]].append(line[0])
+        except Exception:
+            chld[line[1]] = [line[0]]
+        prnt[line[0]] = line[1]
+    elif line[0] != 1 or line[1] != 1:
+        logging.error("cycle detected: \t%d \t%d" % (line[0], line[1]))
 
-    if not l[0] in rankmap:
-        rankmap[l[0]] = l[2]
+    if not line[0] in rankmap:
+        rankmap[line[0]] = line[2]
     else:
         logging.error("duplicate rank in nodes.dmp: \n\t%d %s\t%s" %
-                      (l[0], l[2], rankmap[l[0]]))
+                      (line[0], line[2], rankmap[line[0]]))
 ndsdmp.close()
 
 
 logging.info("reading merged")
 mrgdmp = open(args.merged)
-for l in mrgdmp.readlines():
-    l = l.split("|")
-    l = [x.strip() for x in l]
-    old = int(l[0])
-    new = int(l[1])
+for line in mrgdmp.readlines():
+    line = line.split("|")
+    line = [x.strip() for x in line]
+    old = int(line[0])
+    new = int(line[1])
 
-    if not new in prnt:
+    if new not in prnt:
         print("missing merged new", new)
         continue
 
     p = prnt[new]
 
-    if not old in chld[p]:
+    if old not in chld[p]:
         chld[p].append(old)
 
     prnt[old] = prnt[new]
@@ -170,7 +165,7 @@ for f in os.listdir(args.gbdir):
     acctaxid[gb.accession] = gb.taxid
     try:
         taxidacc[gb.taxid].append(gb.accession)
-    except:
+    except Exception:
         taxidacc[gb.taxid] = [gb.accession]
 
     accgb[gb.accession] = gb
